#!/your/ruby/path
# 
# Test script created by Packet Storm Security, LLC 
# Use to test API requests to api.packetstormsecurity.com
#
# Please remember to comment / uncomment fields as required.
#
# The url variable should point to the correct environment (dev or prod).
# The api_secret_file_path variable should point to the correct key for the given environment.
# The body variable should include the request variables.
#

require 'net/http'
require 'uri'
require 'json'

# url to the dev api 
url = "https://api.packetstormsecurity.com/v31337.20240702/dev-api"

# url to the production api
#url = "https://api.packetstormsecurity.com/v31337.20240702/api"

# path to your dev secret
api_secret_file_path = "./2024-12-14_PACKETSTORM_DEVKEY_1.txt"

# path to your production secret
#api_secret_file_path = "./2024-12-14_PACKETSTORM_PRODUCTION_KEY_1.txt"

# get list of valid areas you can query example
body = %Q|list="areas"|

# get list of valid sections for a given area examples
#body = %Q|area="files"&list="sections"|
#body = %Q|area="news"&list="sections"|

# search files with valid sort method examples
#body = %Q|area=files&section=search&terms="race condition"+heartbleed&page=2&sort="relevant"|
#body = %Q|area=files&section=search&terms="race condition"+hacker&page=1&sort="newest"|
#body = %Q|area=files&section=search&terms=compromise+attacker&page=1&sort="newest"|

# search news with valid sort method examples
#body = %Q|area=news&section=search&terms="hackers target"+microsoft&page=1&sort=relevant|
#body = %Q|area=news&section=search&terms="hackers target"+microsoft&page=1&sort="newest"|

# direct file section query examples
#body = %Q|area=files&section=main&page=1|
#body = %Q|area=files&section=os:apple&page=1|
#body = %Q|area=files&section=main&page=2|
#body = %Q|area=files&section=2023-12&page=1|
#body = %Q|area=files&section=exploit&page=1|
#body = %Q|area=files&section=advisory&page=1|
#body = %Q|area=files&section=exploit&page=1&output=xml|
#body = %Q|area=files&section=exploit&page=1&output=json|

# direct file entry metadata extraction example
#body = %Q|area=files&section=fileentry&id=176323|

# direct news section query examples
#body = %Q|area=news&section=email&page=1&output=json|
#body = %Q|area=news&section=government&page=1&output=xml|
#body = %Q|area=news&section=main&page=2&output=xml|
#body = %Q|area=news&section=linux&page=1&output=json|

# direct news entry metadata extraction example
#body = %Q|area=news&section=newsentry&id=34900|

# cve data example
#body = %Q|area=files&section=cve&id=CVE-2023-22518&page=1|

def read_api_secret_from_file(file_path)
  File.read(file_path).strip
end

def make_post_request(url, body, api_secret)

  # set up request
  uri = URI.parse(url)
  https = Net::HTTP.new(uri.host, uri.port)
  https.use_ssl = true

  request = Net::HTTP::Post.new(uri.request_uri)
  request.body = body
  request['apisecret'] = api_secret

  response = https.request(request)

  content_type = response['Content-Type']
  if content_type.include?('application/xml') || content_type.include?('text/xml')
    puts "XML output"
    # XML response
    if response.code == "200"
      puts "Request successful!"
      puts "Response body: " + response.body.to_s
    else
      puts "Request failed with code #{response.code}"
      puts "Response body: " + response.body.to_s
    end
  elsif content_type.include?('application/json')
    puts "JSON output"
    # JSON response
    z = JSON.parse(response.body)
    z = JSON.pretty_generate(z)
    if response.code == "200"
      puts "Request successful!"
      puts "Response body: " + z.to_s
    else
      puts "Request failed with code #{response.code}"
      puts "Response body: " + z.to_s
    end
  end
end



# read in your secret
api_secret = read_api_secret_from_file(api_secret_file_path)

# create post request
make_post_request(url, body, api_secret)
